========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/sahara.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

OpenStack Data Processing ("Sahara") Spark Plugin
==================================================

OpenStack Sahara Spark Plugin provides the users the option to
start Spark clusters on OpenStack Sahara.
Check out OpenStack Sahara documentation to see how to deploy the
Spark Plugin.

Sahara at wiki.openstack.org: https://wiki.openstack.org/wiki/Sahara

Storyboard project: https://storyboard.openstack.org/#!/project/openstack/sahara-plugin-spark

Sahara docs site: https://docs.openstack.org/sahara/latest/

Quickstart guide: https://docs.openstack.org/sahara/latest/user/quickstart.html

How to participate: https://docs.openstack.org/sahara/latest/contributor/how-to-participate.html

Source: https://opendev.org/openstack/sahara-plugin-spark

Bugs and feature requests: https://storyboard.openstack.org/#!/project/openstack/sahara-plugin-spark

Release notes: https://docs.openstack.org/releasenotes/sahara-plugin-spark/

License
-------

Apache License Version 2.0 http://www.apache.org/licenses/LICENSE-2.0

